@@ -5,12 +5,12 @@ fn main() {
         || 1,
         |count, cx| {
             vstack((
-                text(&format!("{}", cx[count])).padding(Auto),
-                button(text("increment"), move |cx| {
+                format!("{}", cx[count]).padding(Auto),
+                button("increment", move |cx| {
                     cx[count] += 1;
                 })
                 .padding(Auto),
-                button(text("decrement"), move |cx| {
+                button("decrement", move |cx| {
                     cx[count] -= 1;
                 })
                 .padding(Auto),
