@@ -2,6 +2,6 @@ use rui::*;
 
 fn main() {
     rui(list(vec![7, 42, 666], |i| {
-        hstack((circle(), text(&format!("{:?}", i))))
+        hstack((circle(), format!("{:?}", i)))
     }));
 }
