@@ -1,12 +1,14 @@
 use rui::*;
 
+// Requires tao instead of winit for menus.
+// Run with: cargo run --example menu --no-default-features --features tao
+
 fn main() {
     rui(hstack((
-        circle().color(RED_HIGHLIGHT).padding(Auto).command(
-            "File:New",
-            Some(KeyCode::KeyN),
-            |_| println!("new"),
-        ),
+        circle()
+            .color(RED_HIGHLIGHT)
+            .padding(Auto)
+            .command("File:New", Some(HotKey::KeyN), |_| println!("new")),
         rectangle()
             .corner_radius(5.0)
             .color(AZURE_HIGHLIGHT)
@@ -17,6 +19,6 @@ fn main() {
             .command("Custom:Submenu:Two", None, |_| println!("submenu two"))
             .command_group((command("Custom 2:Four")
                 .action(|| println!("four"))
-                .hotkey(KeyCode::KeyF),)),
+                .hotkey(HotKey::KeyF),)),
     )));
 }
