@@ -12,32 +12,27 @@ pub trait View: private::Sealed + 'static {
     fn print(&self, id: ViewId, cx: &mut Context);
 
     /// Processes an event.
-    fn process(&self, _event: &Event, _id: ViewId, _cx: &mut Context, _vger: &mut VGER) {}
+    fn process(&self, _event: &Event, _id: ViewId, _cx: &mut Context, _vger: &mut Vger) {}
 
     /// Draws the view using vger.
-    fn draw(&self, id: ViewId, cx: &mut Context, vger: &mut VGER);
+    fn draw(&self, id: ViewId, cx: &mut Context, vger: &mut Vger);
 
     /// Lays out subviews and return the size of the view.
-    fn layout(&self, id: ViewId, sz: LocalSize, cx: &mut Context, vger: &mut VGER) -> LocalSize;
+    fn layout(&self, id: ViewId, sz: LocalSize, cx: &mut Context, vger: &mut Vger) -> LocalSize;
 
     /// Determines dirty regions which need repainting.
-    fn dirty(
-        &self,
-        _id: ViewId,
-        _xform: LocalToWorld,
-        _cx: &mut Context,
-        _region: &mut Region<WorldSpace>,
-    ) {
-    }
+    fn dirty(&self, _id: ViewId, _xform: LocalToWorld, _cx: &mut Context) {}
 
     /// Returns the topmost view which the point intersects.
     fn hittest(
         &self,
-        id: ViewId,
-        pt: LocalPoint,
-        cx: &mut Context,
-        vger: &mut VGER,
-    ) -> Option<ViewId>;
+        _id: ViewId,
+        _pt: LocalPoint,
+        _cx: &mut Context,
+        _vger: &mut Vger,
+    ) -> Option<ViewId> {
+        None
+    }
 
     /// Accumulates information about menu bar commands.
     fn commands(&self, _id: ViewId, _cx: &mut Context, _cmds: &mut Vec<CommandInfo>) {}
@@ -51,6 +46,12 @@ pub trait View: private::Sealed + 'static {
         _id: ViewId,
         _cx: &mut Context,
         _nodes: &mut Vec<accesskit::Node>,
-    ) -> Option<accesskit::NodeId> { None }
-}
+    ) -> Option<accesskit::NodeId> {
+        None
+    }
 
+    /// For detecting flexible sized things in stacks.
+    fn is_flexible(&self) -> bool {
+        false
+    }
+}
