@@ -1,3 +1,5 @@
+mod anim;
+pub use anim::*;
 mod anyview;
 pub use anyview::*;
 mod background;
@@ -14,6 +16,8 @@ mod emptyview;
 pub use emptyview::*;
 mod env;
 pub use env::*;
+mod flex;
+pub use flex::*;
 mod focus;
 pub use focus::*;
 mod geom;
@@ -24,6 +28,8 @@ mod knob;
 pub use knob::*;
 mod list;
 pub use list::*;
+mod map;
+pub use map::*;
 mod modview;
 pub use modview::*;
 mod offset;
@@ -38,6 +44,8 @@ mod size;
 pub use size::*;
 mod slider;
 pub use slider::*;
+mod spacer;
+pub use spacer::*;
 mod stack;
 pub use stack::*;
 mod state;
